@@ -8,7 +8,7 @@ DBIx::TempDB - Create a temporary database
 
 =head1 VERSION
 
-0.11
+0.12
 
 =head1 SYNOPSIS
 
@@ -97,7 +97,7 @@ use constant KILL_SLEEP_INTERVAL => $ENV{DBIX_TEMP_DB_KILL_SLEEP_INTERVAL} || 2;
 use constant MAX_NUMBER_OF_TRIES => $ENV{DBIX_TEMP_DB_MAX_NUMBER_OF_TRIES} || 20;
 use constant MAX_OPEN_FDS => eval { use POSIX qw( sysconf _SC_OPEN_MAX ); sysconf(_SC_OPEN_MAX) } || 1024;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 our %SCHEMA_DATABASE = (pg => 'postgres', mysql => 'mysql');
 my $N = 0;
 
@@ -263,11 +263,9 @@ Setting "drop_from_child" to a true value will create a child process which
 will remove the temporary database, when the main process ends. There are two
 possible values:
 
-C<drop_from_child=1> will create a child process which monitor the
-L<DBIx::TempDB> object with a pipe. This will then DROP the temp database if
-the object goes out of scope or if the process ends.
-
-TODO: C<drop_from_child=1> might become the default.
+C<drop_from_child=1> (the default) will create a child process which monitor
+the L<DBIx::TempDB> object with a pipe. This will then DROP the temp database
+if the object goes out of scope or if the process ends.
 
 C<drop_from_child=2> will create a child process detached from the parent,
 which monitor the parent with C<kill(0, $parent)>.
@@ -308,9 +306,9 @@ sub new {
 
   $self->{create_database_command} ||= 'create database %d';
   $self->{drop_database_command}   ||= 'drop database %d';
-  $self->{drop_from_child}         ||= 0;
-  $self->{schema_database}         ||= $SCHEMA_DATABASE{$url->canonical_engine};
-  $self->{template}                ||= 'tmp_%U_%X_%H%i';
+  $self->{drop_from_child} //= 1;
+  $self->{schema_database} ||= $SCHEMA_DATABASE{$url->canonical_engine};
+  $self->{template} ||= 'tmp_%U_%X_%H%i';
   warn "[TempDB:$$] schema_database=$self->{schema_database}\n" if DEBUG;
 
   $self->{drop_from_child} = 0 if $ENV{DBIX_TEMP_DB_KEEP_DATABASE};
@@ -388,7 +386,7 @@ sub _dsn_for_pg {
 
   $url = URI::db->new($url);
   $url->dbname($database_name);
-  $url->query_param_delete($_) for $url->query_param;
+  $url->query(undef);
   if (my $service = delete $opt{service}) { $url->query_param(service => $service) }
   $dsn = $url->dbi_dsn;
   @userinfo = ($url->user, $url->password);
@@ -408,7 +406,7 @@ sub _dsn_for_mysql {
 
   $url = URI::db->new($url);
   $url->dbname($database_name);
-  $url->query_param_delete($_) for $url->query_param;
+  $url->query(undef);
   $dsn = $url->dbi_dsn;
   @userinfo = ($url->user, $url->password);
 
@@ -427,7 +425,7 @@ sub _dsn_for_sqlite {
 
   $url = URI::db->new($url);
   $url->dbname($database_name);
-  $url->query_param_delete($_) for $url->query_param;
+  $url->query(undef);
   my $dsn = $url->dbi_dsn;
 
   $opt{AutoCommit}          //= 1;
